@@ -9,24 +9,33 @@ package IkiWiki::Plugin::htmltidy;
 
 use warnings;
 use strict;
-use IkiWiki 2.00;
+use IkiWiki 3.00;
 use IPC::Open2;
 
-sub import { #{{{
+sub import {
+	hook(type => "getsetup", id => "tidy", call => \&getsetup);
 	hook(type => "sanitize", id => "tidy", call => \&sanitize);
-} # }}}
+}
 
-sub sanitize (@) { #{{{
+sub getsetup () {
+	return
+		plugin => {
+			safe => 1,
+			rebuild => undef,
+		},
+}
+
+sub sanitize (@) {
 	my %params=@_;
 
 	my $pid;
 	my $sigpipe=0;
 	$SIG{PIPE}=sub { $sigpipe=1 };
-	$pid=open2(*IN, *OUT, 'tidy -quiet -asxhtml -utf8 --show-body-only yes --show-warnings no --tidy-mark no');
-	
+	$pid=open2(*IN, *OUT, 'tidy -quiet -asxhtml -utf8 --show-body-only yes --show-warnings no --tidy-mark no --markup yes 2>/dev/null');
+
 	# open2 doesn't respect "use open ':utf8'"
 	binmode (IN, ':utf8');
-	binmode (OUT, ':utf8'); 
+	binmode (OUT, ':utf8');
 	
 	print OUT $params{content};
 	close OUT;
@@ -36,10 +45,12 @@ sub sanitize (@) { #{{{
 	close IN;
 	waitpid $pid, 0;
 
-	return $params{content} if $sigpipe;
 	$SIG{PIPE}="DEFAULT";
+	if ($sigpipe || ! defined $ret) {
+		return gettext("htmltidy failed to parse this html");
+	}
 
 	return $ret;
-} # }}}
+}
 
 1
