@@ -3,37 +3,59 @@ package IkiWiki::Plugin::shortcut;
 
 use warnings;
 use strict;
-use IkiWiki 2.00;
+use IkiWiki 3.00;
 
-sub import { #{{{
+sub import {
+	hook(type => "getsetup", id => "shortcut", call => \&getsetup);
 	hook(type => "checkconfig", id => "shortcut", call => \&checkconfig);
 	hook(type => "preprocess", id => "shortcut", call => \&preprocess_shortcut);
-} #}}}
+}
 
-sub checkconfig () { #{{{
-	# Preprocess the shortcuts page to get all the available shortcuts
-	# defined before other pages are rendered.
-	IkiWiki::preprocess("shortcuts", "shortcuts",
-		readfile(srcfile("shortcuts.mdwn")));
-} # }}}
+sub getsetup () {
+	return
+		plugin => {
+			safe => 1,
+			rebuild => undef,
+			section => "widget",
+		},
+}
 
-sub preprocess_shortcut (@) { #{{{
+sub checkconfig () {
+	if (defined $config{srcdir} && length $config{srcdir}) {
+		# Preprocess the shortcuts page to get all the available shortcuts
+		# defined before other pages are rendered.
+		my $srcfile=srcfile("shortcuts.".$config{default_pageext}, 1);
+		if (! defined $srcfile) {
+			$srcfile=srcfile("shortcuts.mdwn", 1);
+		}
+		if (! defined $srcfile) {
+			print STDERR sprintf(gettext("shortcut plugin will not work without %s"),
+				"shortcuts.".$config{default_pageext})."\n";
+		}
+		else {
+			IkiWiki::preprocess("shortcuts", "shortcuts", readfile($srcfile));
+		}
+	}
+}
+
+sub preprocess_shortcut (@) {
 	my %params=@_;
 
 	if (! defined $params{name} || ! defined $params{url}) {
-		return "[[shortcut ".gettext("missing name or url parameter")."]]";
+		error gettext("missing name or url parameter");
 	}
 
 	hook(type => "preprocess", no_override => 1, id => $params{name},
+		shortcut => 1,
 		call => sub { shortcut_expand($params{url}, $params{desc}, @_) });
 
 	#translators: This is used to display what shortcuts are defined.
 	#translators: First parameter is the name of the shortcut, the second
 	#translators: is an URL.
 	return sprintf(gettext("shortcut %s points to <i>%s</i>"), $params{name}, $params{url});
-} # }}}
+}
 
-sub shortcut_expand ($$@) { #{{{
+sub shortcut_expand ($$@) {
 	my $url=shift;
 	my $desc=shift;
 	my %params=@_;
@@ -53,8 +75,15 @@ sub shortcut_expand ($$@) { #{{{
 	my $text=join(" ", @params);
 	my $encoded_text=$text;
 	$encoded_text=~s/([^A-Za-z0-9])/sprintf("%%%02X", ord($1))/seg;
+	
+	$url=~s{\%([sS])}{
+		$1 eq 's' ? $encoded_text : $text
+	}eg;
 
 	$text=~s/_/ /g;
+	if (defined $params{desc}) {
+		$desc=$params{desc};
+	}
 	if (defined $desc) {
 		$desc=~s/\%s/$text/g;
 	}
@@ -62,8 +91,7 @@ sub shortcut_expand ($$@) { #{{{
 		$desc=$text;
 	}
 
-	$url=~s/\%s/$encoded_text/g;
 	return "<a href=\"$url\">$desc</a>";
-} #}}}
+}
 
 1
